@@ -47,7 +47,6 @@ class Constants(object):
         environment / config section from default to __CONSTANTS__
         filename is the config filename
         """
-        # in python 3 prevents an endless recursion getattr / getitem
         object.__setattr__(self, 'dict', {})
         self.variable = variable
         self.filename = filename
@@ -108,26 +107,21 @@ class Constants(object):
 
     @staticmethod
     @debug
-    def cast(string):
+    def cast(constant):
         """
         cast string to int, float or keep as string
-
-        >>> Constants.cast('1')
-        1
-        >>> Constants.cast('3.14')
-        3.14
-        >>> Constants.cast('a_string')
-        'a_string'
         """
+        if hasattr(constant, 'startswith') and constant.startswith('0'):
+            return constant
         try:
-            return int(string)
+            return int(constant)
         except ValueError:
             pass
         try:
-            return float(string)
+            return float(constant)
         except ValueError:
             pass
-        return string
+        return constant
 
     @debug
     def __setitem__(self, item, value):
